% jitterViabilityKernelVisualize: generate a pretty plot
%
% This script runs jitterViabilityKernel(), and then generates a pretty
% visualization which shades in the target.

% Copyright 2014 Ian M. Mitchell (mitchell@cs.ubc.ca).
% This software is used, copied and distributed under the licensing 
%   agreement contained in the file LICENSE in the top directory of 
%   the distribution.
%
% Created by Ian Mitchell, 2009/11/28
% Modified to the viability kernel example, 2012/09/28
% Modified to the jitter kernel example, 2014/10/18

  % Generate the viability kernel.  These are the settings used in the
  % figure from the paper; they take a long time to run.  The default
  % settings generate less accurate results but require much less time to
  % execute.
  max_steps = 5;
  delta_fixed = 1.0;
  delta_jitter = 0.0;
  accuracy = 'veryHigh'; 
  %accuracy = 'medium';
  input_samples = 25;
  state_dx = 0.01;
  %state_dx = 0.02;
  %[ g, kernels ] = jitterViabilityKernelL(max_steps, delta_fixed, delta_jitter, accuracy, input_samples, state_dx);
  [ g, kernels ] = jitterViabilityKernelStep(max_steps, delta_fixed, delta_jitter, accuracy, input_samples, state_dx);
  
  % Get rid of the figure generated during computation.
  close;
  
  % Convert the viability kernels over various horizons into a single
  % stepped function.  Regions outside the constraint will be -1 and
  % regions in K_n for step n will have value n. We need to work our way
  % forwards through the set of finite horizon sampled data viability
  % kernels because each viability kernel at step n-1 contains the kernel
  % at step n.
  summary = -ones(g.shape);
  for i = 1 : max_steps + 1;
    summary(kernels{i} <= 0) = i-1;
  end
  
  % Create the plot.
  figure;
  level_subsampling = 10;
  contourf(g.xs{:}, summary, 0 : (1 / level_subsampling) : max_steps);
  title(sprintf('Sampled Data Viability Kernel \\delta^F = %3.1f, \\delta^J = %3.1f, N = %d', ...
        delta_fixed, delta_jitter, max_steps))
  grid on;
  axis equal;
  axis(g.axis);
  
  % Make the color scheme more amenable to B&W printing.
  grayscale = gray(level_subsampling * (max_steps + 6));
  colormap(grayscale(4 * level_subsampling : end-(2 * level_subsampling), :));
    
  xlabel('x_1');  ylabel('x_2');
  